The View system
===============

This chapter aims to describe the concept of a `view` used all along
the development of a web application and how it has been implemented
in |cubicweb|.


.. toctree::
   :maxdepth: 3

   views
   basetemplates
   primary
   reledit
   baseviews
   startup
   boxes
   table
   xmlrss
..   editforms

.. toctree::
   :maxdepth: 3

   urlpublish
   breadcrumbs
..   wdoc
..   embedding
..   idownloadable

